@@ -34,29 +34,10 @@
  * Determine platform-dependent configuration.
  */
 
-#if defined(macintosh) || (defined(__MACH__) && defined(__APPLE__))
-#include <TargetConditionals.h>
-#if TARGET_RT_MAC_CFM
-#error "Use KfM 4.0 SDK headers for CFM compilation."
-#endif
-#endif
-
 #ifdef __cplusplus
 extern          "C" {
 #endif				/* __cplusplus */
 
-#if TARGET_OS_MAC
-#if defined(__MWERKS__)
-#pragma import on
-#pragma enumsalwaysint on
-#endif
-#pragma options align=mac68k
-#endif
-
-#if defined(_MSDOS) || defined(_WIN32)
-#include <win-mac.h>
-#endif
-
 #include <stdint.h>
 
     /*
@@ -67,9 +48,7 @@ extern          "C" {
     /*
      * POSIX says that sys/types.h is where size_t is defined.
      */
-#ifndef macintosh
 #include <sys/types.h>
-#endif
 
     /*
      * $Id: gssapi.h.in,v 1.2 2006/04/08 20:27:24 kwc Exp $
@@ -829,14 +808,6 @@ extern          "C" {
 					       void *	/* ktypes */
 	);
 
-#if TARGET_OS_MAC
-#if defined(__MWERKS__)
-#pragma enumsalwaysint reset
-#pragma import reset
-#endif
-#pragma options align=reset
-#endif
-
     /*
      * XXXX these are not part of the GSSAPI C bindings! (but should be)
      */
